@@ -64,3 +64,24 @@ class GeoObjectPost(GeoObject):
     def gettimeout(self):
         return self.timeout
 
+    def setremarks(self, remarks):
+        self.remarks = remarks
+
+    def getremarks(self):
+        return self.remarks
+
+    def setrepeat(self, repeat: bool):
+        """the new repeat value for this instance
+
+        Args:
+            repeat (bool): whether or not the message should be repeated
+        """
+        self.repeat = repeat
+        
+    def getrepeat(self) -> bool:
+        """get the repeat value for this instance
+
+        Returns:
+            bool: whether or not the geo object should be repeated 
+        """
+        return self.repeat
\ No newline at end of file
