@@ -52,4 +52,10 @@ class PresencePost(Presence):
         self.timeout = timeout
 
     def gettimeout(self):
-        return self.timeout
\ No newline at end of file
+        return self.timeout
+
+    def setremarks(self, remarks):
+        self.remarks = remarks
+
+    def getremarks(self):
+        return self.remarks
\ No newline at end of file
